oujago
======


Coding makes the life easier. This is a factory contains commonly used
algorithms. OUJAGO is a work in progress, input is welcome. The project is on
`GitHub <https://github.com/oujago/oujago>`_.


Language
========

.. toctree::
    :maxdepth: 1

    nlp/segment
    nlp/postag
    nlp/nertag
    nlp/dependence
    nlp/srl
    nlp/fjconvert
    nlp/stopwords

NeuralNetwork
=============

.. toctree::
    :maxdepth: 1

    nn/keras_resnet


DataTypes
=========

.. toctree::
    :maxdepth: 1

    datatypes/queue
    datatypes/stack



Utils
=====

.. toctree::
    :maxdepth: 1

    utils/common
    utils/file
    utils/time
    utils/data



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _GitHub: https://github.com/oujago/oujago


